ObjectConfig

Struct ObjectConfig 

pub struct ObjectConfig {
    pub endpoint: String,
    pub private_key: String,
    pub public_key: String,
    pub region: String,
    pub proxy_suffix: Option<String>,
    pub custom_host: Option<String>,
    pub protocol: UfileProtocol,
}
Re-export configuration for s3 credential Configuration for Ucloud object operations. This struct holds the necessary information such as region, proxy suffix, and custom host to interact with Ucloud object storage.

Fields

endpoint: String

default http request endpoint.

private_key: String

private key

public_key: String

public key

region: String

仓库地区 (eg: ‘cn-bj’)

proxy_suffix: Option<String>

代理后缀 (eg: ‘ufileos.com’)

custom_host: Option<String>

自定义域名 (eg: ‘api.ucloud.cn’):若配置了非空自定义域名,则使用自定义域名,不会使用 region + proxySuffix 拼接

protocol: UfileProtocol

protocol

Implementations

Source

impl ObjectConfig

pub fn generate_final_host(&self, bucket_name: &str, key_name: &str) -> String

A method to generate the final request full hosts.

pub fn authorization_private_url( &self, method: Method, bucket_name: &str, key_name: &str, expires: &str, ) -> Result<String, Error>

This method is used to generate private url which contains signature and expire time.

Arguments
  • method - The http method.
  • bucket_name - The name of the bucket.
  • key_name - The name of the object.
  • expires - The expire time of the url. unit: second.