pub struct HttpClient { /* private fields */ }Implementations
Sourceimpl HttpClient
impl HttpClient
pub fn builder() -> HttpClientBuilder
pub fn get_client(&self) -> &Client
pub fn into_inner(self) -> Client
Sourceimpl HttpClient
impl HttpClient
Sourcepub async fn send_file(
&self,
url: &str,
method: Method,
headers: HeaderMap,
stream: ByteStream,
) -> Result<BaseResponse, Error>
pub async fn send_file( &self, url: &str, method: Method, headers: HeaderMap, stream: ByteStream, ) -> Result<BaseResponse, Error>
This method support only files which is smaller than 512MB, otherwise, will return error. If you are trying to upload a file that is more than 512MB, please use multipart upload which is supported by ucloud (Which should create multiple slices to upload).